.title Requirements

## System Requirements

* **GPU:** Graphic card with OpenGL 3.3, Direct3D 11 or OpenGL ES 3.1 support.
* **CPU** and **memory** requirements are mostly dependent on your project characteristics.

A faster computer for development is recommended.

### Supported desktop OS

* Windows 10+ (Intel)
* Ubuntu 20.04 LTS+ (Intel)
* Aarch Linux 64 (ARM)

### Window systems
* X11
* Wayland

### VR Support
* Via SteamVR (Windows only)

